@@ -1,7 +1,7 @@
 package AppBase::Grep;
 
 our $DATE = '2018-01-29'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,9 +29,14 @@ _
     args => {
         pattern => {
             schema => 're*',
-            req => 1,
             pos => 0,
         },
+        regexps => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'regexp',
+            schema => ['array*', of=>'re*'],
+            cmdline_aliases => {e=>{code=>sub { $_[0]{regexps} //= []; push @{$_[0]{regexps}}, $_[1] }}},
+        },
 
         ignore_case => {
             schema => 'bool*',
@@ -44,6 +49,11 @@ _
             cmdline_aliases => {v=>{}},
             tags => ['category:matching-control'],
         },
+        all => { # not in grep
+            summary => 'Require all patterns to match, instead of just one',
+            schema => 'true*',
+            tags => ['category:matching-control'],
+        },
         count => {
             summary => 'Supress normal output, return a count of matching lines',
             schema => 'true*',
@@ -81,12 +91,19 @@ sub grep {
     my $opt_count  = $args{count};
     my $opt_quiet  = $args{quiet};
     my $opt_linum  = $args{line_number};
-    my $pat        = $opt_ci ? qr/$args{pattern}/i : qr/$args{pattern}/;
+
+    my (@str_patterns, @re_patterns);
+    for my $p ( grep {defined} $args{pattern}, @{ $args{regexps} // [] }) {
+        push @str_patterns, $p;
+        push @re_patterns , $opt_ci ? qr/$p/i : qr/$p/;
+    }
+    return [400, "Please specify at least one pattern"] unless @re_patterns;
+    my $re_pat = join('|', @str_patterns);
+    $re_pat = $opt_ci ? qr/$re_pat/i : qr/$re_pat/;
 
     my $color = $args{color} //
         (defined $ENV{COLOR} ? ($ENV{COLOR} ? 'always' : 'never') : undef) //
         'auto';
-
     my $use_color;
     if ($color eq 'always') {
         $use_color = 1;
@@ -95,8 +112,12 @@ sub grep {
     } else {
         $use_color = (-t STDOUT);
     }
+
     my $source = $args{_source};
 
+    my $logic = 'or';
+    $logic = 'and' if $args{all};
+
     my $num_matches = 0;
     my ($line, $label, $linum);
 
@@ -117,8 +138,8 @@ sub grep {
             }
         }
 
-        if ($use_color && !$opt_invert) {
-            $line =~ s/($pat)/$Colors{match}$1\e[0m/g;
+        if ($use_color) {
+            $line =~ s/($re_pat)/$Colors{match}$1\e[0m/g;
             print $line;
         } else {
             print $line;
@@ -146,9 +167,26 @@ sub grep {
             }
         }
 
-        my $is_match = 0;
-        if ($line =~ $pat) {
+        my $is_match;
+        if ($logic eq 'or') {
+            $is_match = 0;
+            for my $re (@re_patterns) {
+                if ($line =~ $re) {
+                    $is_match = 1;
+                    last;
+                }
+            }
+        } else {
             $is_match = 1;
+            for my $re (@re_patterns) {
+                unless ($line =~ $re) {
+                    $is_match = 0;
+                    last;
+                }
+            }
+        }
+
+        if ($is_match) {
             next if $opt_invert;
             if ($opt_quiet || $opt_count) {
                 $num_matches++;
@@ -188,7 +226,7 @@ AppBase::Grep - A base for grep-like CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.002 of AppBase::Grep (from Perl distribution AppBase-Grep), released on 2018-01-29.
+This document describes version 0.003 of AppBase::Grep (from Perl distribution AppBase-Grep), released on 2018-01-29.
 
 =head1 FUNCTIONS
 
@@ -211,6 +249,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Require all patterns to match, instead of just one.
+
 =item * B<color> => I<str>
 
 =item * B<count> => I<true>
@@ -225,10 +267,12 @@ Invert the sense of matching.
 
 =item * B<line_number> => I<true>
 
-=item * B<pattern>* => I<re>
+=item * B<pattern> => I<re>
 
 =item * B<quiet> => I<true>
 
+=item * B<regexps> => I<array[re]>
+
 =back
 
 Returns an enveloped result (an array).
